@@ -8,13 +8,19 @@ import (
 // DetectedVulnerability holds the information of detected vulnerabilities
 type DetectedVulnerability struct {
 	VulnerabilityID  string       `json:",omitempty"`
+	VendorIDs        []string     `json:",omitempty"`
 	PkgName          string       `json:",omitempty"`
+	PkgPath          string       `json:",omitempty"` // It will be filled in the case of language-specific packages such as egg/wheel and gemspec
 	InstalledVersion string       `json:",omitempty"`
 	FixedVersion     string       `json:",omitempty"`
 	Layer            ftypes.Layer `json:",omitempty"`
 	SeveritySource   string       `json:",omitempty"`
 	PrimaryURL       string       `json:",omitempty"`
 
+	// Custom is for extensibility and not supposed to be used in OSS
+	Custom interface{} `json:",omitempty"`
+
+	// Embed vulnerability details
 	types.Vulnerability
 }
 
